@@ -47,6 +47,7 @@ class Encoder(torch.nn.Module):
         hidden_layers_processor_node=2,
         hidden_layers_processor_edge=2,
         mlp_norm_type="LayerNorm",
+        use_checkpointing: bool = False,
     ):
         """
         Encode the lat/lon data inot the isohedron graph
@@ -63,8 +64,10 @@ class Encoder(torch.nn.Module):
             hidden_layers_processor_edge: Number of hidden layers in the edge processors
             mlp_norm_type: Type of norm for the MLPs
                 one of 'LayerNorm', 'GraphNorm', 'InstanceNorm', 'BatchNorm', 'MessageNorm', or None
+            use_checkpointing: Whether to use gradient checkpointing to use less memory
         """
         super().__init__()
+        self.use_checkpointing = use_checkpointing
         self.output_dim = output_dim
         self.num_latlons = len(lat_lons)
         self.base_h3_grid = sorted(list(h3.uncompact(h3.get_res0_indexes(), resolution)))
@@ -117,6 +120,7 @@ class Encoder(torch.nn.Module):
             hidden_dim_processor_node,
             hidden_layers_processor_node,
             mlp_norm_type,
+            self.use_checkpointing,
         )
         self.edge_encoder = MLP(
             2,
@@ -124,6 +128,7 @@ class Encoder(torch.nn.Module):
             hidden_dim_processor_edge,
             hidden_layers_processor_edge,
             mlp_norm_type,
+            self.use_checkpointing,
         )
         self.latent_edge_encoder = MLP(
             2,
@@ -131,6 +136,7 @@ class Encoder(torch.nn.Module):
             hidden_dim_processor_edge,
             hidden_layers_processor_edge,
             mlp_norm_type,
+            self.use_checkpointing,
         )
         self.graph_processor = GraphProcessor(
             1,
